@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2015-2023 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -11,19 +11,15 @@
 #include <PimCommon/NetworkManager>
 
 #include <QCryptographicHash>
-#include <QNetworkConfigurationManager>
 #include <QNetworkReply>
 #include <QUrlQuery>
 
 using namespace Gravatar;
 
-class Q_DECL_HIDDEN Gravatar::GravatarResolvUrlJobPrivate
+class Gravatar::GravatarResolvUrlJobPrivate
 {
 public:
-    GravatarResolvUrlJobPrivate()
-    {
-    }
-
+    GravatarResolvUrlJobPrivate() = default;
     QPixmap mPixmap;
     QString mEmail;
     Hash mCalculatedHash;
@@ -43,14 +39,11 @@ GravatarResolvUrlJob::GravatarResolvUrlJob(QObject *parent)
 {
 }
 
-GravatarResolvUrlJob::~GravatarResolvUrlJob()
-{
-    delete d;
-}
+GravatarResolvUrlJob::~GravatarResolvUrlJob() = default;
 
 bool GravatarResolvUrlJob::canStart() const
 {
-    if (PimCommon::NetworkManager::self()->networkConfigureManager()->isOnline()) {
+    if (PimCommon::NetworkManager::self()->isOnline()) {
         // qCDebug(GRAVATAR_LOG) << "email " << d->mEmail;
         return !d->mEmail.trimmed().isEmpty() && (d->mEmail.contains(QLatin1Char('@')));
     } else {
@@ -170,10 +163,11 @@ bool GravatarResolvUrlJob::fallbackGravatar() const
 
 void GravatarResolvUrlJob::setFallbackGravatar(bool fallbackGravatar)
 {
-    if (fallbackGravatar)
+    if (fallbackGravatar) {
         d->mBackends |= GravatarResolvUrlJobPrivate::Gravatar;
-    else
+    } else {
         d->mBackends &= ~GravatarResolvUrlJobPrivate::Gravatar;
+    }
 }
 
 bool GravatarResolvUrlJob::useLibravatar() const
@@ -183,10 +177,11 @@ bool GravatarResolvUrlJob::useLibravatar() const
 
 void GravatarResolvUrlJob::setUseLibravatar(bool useLibravatar)
 {
-    if (useLibravatar)
+    if (useLibravatar) {
         d->mBackends |= GravatarResolvUrlJobPrivate::Libravatar;
-    else
+    } else {
         d->mBackends &= ~GravatarResolvUrlJobPrivate::Libravatar;
+    }
 }
 
 bool GravatarResolvUrlJob::useDefaultPixmap() const
