@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2015-2023 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -18,12 +18,10 @@
 using namespace Gravatar;
 using namespace PimCommon::ConfigureImmutableWidgetUtils;
 
-class Q_DECL_HIDDEN Gravatar::GravatarConfigWidgetPrivate
+class Gravatar::GravatarConfigWidgetPrivate
 {
 public:
-    GravatarConfigWidgetPrivate()
-    {
-    }
+    GravatarConfigWidgetPrivate() = default;
 
     QCheckBox *mEnableGravatarSupport = nullptr;
     QPushButton *mConfigureGravatarSetting = nullptr;
@@ -51,10 +49,7 @@ GravatarConfigWidget::GravatarConfigWidget(QWidget *parent)
     updateWidgetState(false);
 }
 
-GravatarConfigWidget::~GravatarConfigWidget()
-{
-    delete d;
-}
+GravatarConfigWidget::~GravatarConfigWidget() = default;
 
 void GravatarConfigWidget::slotConfigureSettings()
 {
